==> typescript-angular-components-1.2.2.tgz: package/source/components/multiStepIndicator/multiStepIndicator.ts <==
// /// <reference path='../../../typings/commonjs.d.ts' />

'use strict';

import * as angular from 'angular';
import * as _ from 'lodash';

import { services } from 'typescript-angular-utilities';

export var moduleName: string = 'rl.ui.components.multiStepIndicator';
export var directiveName: string = 'rlMultiStepIndicator';
export var controllerName: string = 'MultiStepIndicatorController';

import __object = services.object;

export interface IStep {
	title: string;
	subtitle?: string;
	onClick?: {(): angular.IPromise<void> | void};
	stateName?: string;
	count?: {(): number};
	isCompleted?: boolean;
	isCurrent?: boolean;
}

export interface IConfiguredStep extends IStep {
	inactive: boolean;
	loading: boolean;
	hasCount: boolean;
}

export class MultiStepIndicatorController {
	steps: IConfiguredStep[];

	static $inject: string[] = ['$state', '$q', __object.serviceName];
	constructor(private $state: angular.ui.IStateService
			, private $q: angular.IQService
			, private object: __object.IObjectUtility) {
		this.configureSteps();
	}

	onClick(step: IConfiguredStep): void {
		if (!this.anyLoading()) {
			step.loading = true;
			this.$q.when(step.onClick()).then((): void => {
				step.loading = false;
			});
		}
	}

	anyLoading(): boolean {
		return _.any(this.steps, (step: IConfiguredStep): boolean => {
			return step.loading;
		});
	}

	private configureSteps(): void {
		_.each(this.steps, (step: IConfiguredStep): void => {
			step.hasCount = _.isFunction(step.count);

			if (!_.isFunction(step.onClick)) {
				if (this.object.isNullOrWhitespace(step.stateName)) {
					step.inactive = true;
				} else {
					step.onClick = (): angular.IPromise<void> => { return this.redirectToState(step); };

					if (this.$state.includes(step.stateName)) {
						step.isCurrent = true;
					}
				}
			}
		});
	}

	private redirectToState(step: IConfiguredStep): angular.IPromise<void> {
		return this.$state.go(step.stateName).then((): void => {
			this.clearCurrentState();
			step.isCurrent = true;
		});
	}

	private clearCurrentState(): void {
		_.each(this.steps, (step: IStep): void => {
			step.isCurrent = false;
		});
	}
}

function multiStepIndicator(): angular.IDirective {
	'use strict';
	return {
		restrict: 'E',
		template: require('./multiStepIndicator.html'),
		controller: controllerName,
		controllerAs: 'breadcrumb',
		scope: {},
		bindToController: {
			steps: '=',
			numbered: '=',
		},
	};
}

angular.module(moduleName, [__object.moduleName])
	.directive(directiveName, multiStepIndicator)
	.controller(controllerName, MultiStepIndicatorController);

==> typescript-angular-components-1.4.1.tgz: package/source/components/multiStepIndicator/multiStepIndicator.ts <==
// /// <reference path='../../../typings/commonjs.d.ts' />

'use strict';

import * as angular from 'angular';
import * as _ from 'lodash';

import { services } from 'typescript-angular-utilities';

export var moduleName: string = 'rl.ui.components.multiStepIndicator';
export var directiveName: string = 'rlMultiStepIndicator';
export var controllerName: string = 'MultiStepIndicatorController';

import __object = services.object;

export interface IStep {
	title: string;
	subtitle?: string;
	onClick?: {(): angular.IPromise<void> | void};
	stateName?: string;
	count?: {(): number};
	isCompleted?: boolean | {(): boolean};
	isValid?: boolean | {(): boolean};
	isCurrent?: boolean;
}

export interface IConfiguredStep extends IStep {
	inactive: boolean;
	loading: boolean;
	hasCount: boolean;
	getCompleted(): boolean;
	getValid(): boolean;
}

export class MultiStepIndicatorController {
	steps: IConfiguredStep[];

	static $inject: string[] = ['$state', '$q', __object.serviceName];
	constructor(private $state: angular.ui.IStateService
			, private $q: angular.IQService
			, private object: __object.IObjectUtility) {
		this.configureSteps();
	}

	onClick(step: IConfiguredStep): void {
		if (!this.anyLoading()) {
			step.loading = true;
			this.$q.when(step.onClick()).then((): void => {
				step.loading = false;
			});
		}
	}

	anyLoading(): boolean {
		return _.any(this.steps, (step: IConfiguredStep): boolean => {
			return step.loading;
		});
	}

	private configureSteps(): void {
		_.each(this.steps, (step: IConfiguredStep): void => {
			step.hasCount = _.isFunction(step.count);
			step.getCompleted = (): boolean => { return this.getIsCompleted(step); };
			step.getValid = (): boolean => { return this.getIsValid(step); };

			if (!_.isFunction(step.onClick)) {
				if (this.object.isNullOrWhitespace(step.stateName)) {
					step.inactive = true;
				} else {
					step.onClick = (): angular.IPromise<void> => { return this.redirectToState(step); };

					if (this.$state.includes(step.stateName)) {
						step.isCurrent = true;
					}
				}
			}
		});
	}

	private redirectToState(step: IConfiguredStep): angular.IPromise<void> {
		return this.$state.go(step.stateName).then((): void => {
			this.clearCurrentState();
			step.isCurrent = true;
		});
	}

	private clearCurrentState(): void {
		_.each(this.steps, (step: IStep): void => {
			step.isCurrent = false;
		});
	}

	private getIsCompleted(step: IConfiguredStep): boolean {
		return _.isFunction(step.isCompleted)
			? (<{(): boolean}>step.isCompleted)()
			: <boolean>step.isCompleted;
	}

	private setIsCompleted(step: IConfiguredStep, isCompleted: boolean): void {
		if (!_.isFunction(step.isCompleted)) {
			step.isCompleted = isCompleted;
		}
	}

	private getIsValid(step: IConfiguredStep): boolean {
		if (_.isFunction(step.isValid)) {
			return (<{(): boolean}>step.isValid)();
		} else if (!_.isUndefined(step.isValid != null)) {
			return <boolean>step.isValid;
		} else {
			return true;
		}
	}
}

function multiStepIndicator(): angular.IDirective {
	'use strict';
	return {
		restrict: 'E',
		template: require('./multiStepIndicator.html'),
		controller: controllerName,
		controllerAs: 'breadcrumb',
		scope: {},
		bindToController: {
			steps: '=',
			numbered: '=',
		},
	};
}

angular.module(moduleName, [__object.moduleName])
	.directive(directiveName, multiStepIndicator)
	.controller(controllerName, MultiStepIndicatorController);
